You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2021/11/27 14:41:34 UTC

[commons-vfs] 01/04: Better parameter name.

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-vfs.git

commit ebf4744e52301ab5666d757778f2cc9fbe082ef3
Author: Gary Gregory <ga...@gmail.com>
AuthorDate: Sat Nov 27 09:34:44 2021 -0500

    Better parameter name.
---
 .../java/org/apache/commons/vfs2/FileSystemException.java  | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/commons-vfs2/src/main/java/org/apache/commons/vfs2/FileSystemException.java b/commons-vfs2/src/main/java/org/apache/commons/vfs2/FileSystemException.java
index 64a5ac4..d25341b 100644
--- a/commons-vfs2/src/main/java/org/apache/commons/vfs2/FileSystemException.java
+++ b/commons-vfs2/src/main/java/org/apache/commons/vfs2/FileSystemException.java
@@ -103,21 +103,21 @@ public class FileSystemException extends IOException {
      * Constructs exception with the specified detail message.
      *
      * @param code the error code of the message.
      * @param info0 one context information.
      */
-    public FileSystemException(final String code, final Object info0) {
-        this(code, null, new Object[] { info0 });
+    public FileSystemException(final String code, final Object info) {
+        this(code, null, new Object[] { info });
     }
 
     /**
-     * Constructs exception with the specified detail message.
+     * Constructs exception with the specified detail message and cause.
      *
      * @param code the error code of the message.
      * @param info0 one context information.
      * @param throwable the cause.
      */
-    public FileSystemException(final String code, final Object info0, final Throwable throwable) {
-        this(code, throwable, new Object[] { info0 });
+    public FileSystemException(final String code, final Object info, final Throwable throwable) {
+        this(code, throwable, new Object[] { info });
     }
 
     /**
@@ -103,21 +103,21 @@ public class FileSystemException extends IOException {
      *
      * @param code the error code of the message.
-     * @param info0 one context information.
+     * @param info one context information.
      */
@@ -103,21 +103,21 @@ public class FileSystemException extends IOException {
      *
      * @param code the error code of the message.
-     * @param info0 one context information.
+     * @param info one context information.
      * @param throwable the cause.
      */